RandomizedCleaner
=================

.. currentmodule:: pykeen.triples.splitting

.. autoclass:: RandomizedCleaner
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RandomizedCleaner.cleanup_pair

   .. rubric:: Methods Documentation

   .. automethod:: cleanup_pair
